@@ -143,8 +143,6 @@ if (@signatures > 1)
 	$verify_results_text .= "\n";
 }
 
-my $hint_text = check_for_hints();
-
 my $policy_results_text = "";
 for (my $i = 0; $i < @policies; $i++)
 {
@@ -180,10 +178,7 @@ subject.
 }
 
 # part one, literal text containing result of test
-my $PRODUCT = "Mail::DKIM";
-my $VERSION = $Mail::DKIM::VERSION;
-my $PRODUCT_URL = "http://dkimproxy.sourceforge.net/";
-
+my $PRODUCT = "Mail::DKIM " . $Mail::DKIM::VERSION;
 $top->attach(
 	Type => "text/plain",
 	Data => [
@@ -195,10 +190,9 @@ $top->attach(
 		"auto-responder looks for ANY passing signature, including DomainKeys\n",
 		"signatures.\n",
 		"\n",
-		$hint_text,
 		"Thank you for using the dkimproxy DKIM Auto Responder.\n",
-		"This Auto Responder tests the verification routines of $PRODUCT $VERSION.\n",
-		"For more information about $PRODUCT, see $PRODUCT_URL\n",
+		"This Auto Responder tests the verification routines of $PRODUCT.\n",
+		"For more information about Mail::DKIM, see http://jason.long.name/dkimproxy/\n",
 		"\n",
 		"If you have any questions about this automated tester, or if you\n",
 		"received this message in error, please send a note to\n",
@@ -261,25 +255,3 @@ sub debug_canonicalization
 		||= { text => "", canon => $canonicalization };
 	$canonicalized{$canonicalization}->{text} .= $text;
 }
-
-sub check_for_hints
-{
-	my @hints;
-
-	if ($result_detail =~ /body has been altered/)
-	{
-		if (grep /^\./, @message_lines)
-		{
-			push @hints, "Your message contains lines beginning with a period, so check that\n   your implementation signs before dot stuffing.";
-		}
-	}
-
-	if (@hints)
-	{
-		return "*** WHY DID MY MESSAGE FAIL? ***\n"
-		. "Looking at your specific message, this auto-responder suggests\n"
-		. "checking the following:\n"
-		. join("", map " * $_\n", @hints). "\n";
-	}
-	return "";
-}
